%F is the vectorized function to be evaluated
%bound is a vector representing the x,y,z bounds to the integrals
%N is the number of samples to use in the approximation
%e.g. MonteCarlo(inline('x.*y.*z'), [0 1 0 1 0 1], 1000)
function Approx = MonteCarlo(F, bound, N)
     B = bound;
     R = rand(3, N);
     %Set the random samplings to the correct intervals
     R(1, :) = (B(2)-B(1))*R(1, :)+ B(1);
     R(2, :) = R(2, :)*(B(4) - B(3)) + B(3);
     R(3, :) = R(3, :)*(B(6) - B(5)) + B(5);
     Volume = (B(2)-B(1))*(B(4)-B(3))*(B(6)-B(5));
     s = feval(F, R(1,:), R(2,:), R(3,:));
     total = sum(s);
     avgF = total/N;
     Approx = avgF*Volume;
     %fprintf('Approximation: %f', Approx);